# Generated by Django 5.1.5 on 2025-02-27 09:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sample_project", "0004_remove_versiongroup_self_contenttype_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="place",
            name="feature_code",
            field=models.CharField(
                blank=True,
                default="",
                help_text='<a href="https://www.geonames.org/export/codes.html">Geonames Feature Code List</a>',
                max_length=16,
            ),
        ),
        migrations.AddField(
            model_name="versionplace",
            name="feature_code",
            field=models.CharField(
                blank=True,
                default="",
                help_text='<a href="https://www.geonames.org/export/codes.html">Geonames Feature Code List</a>',
                max_length=16,
            ),
        ),
    ]
