# Generated by Django 4.1.10 on 2023-09-21 07:05

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_entities", "0003_remove_tempentityclass_source"),
        ("apis_metainfo", "0006_delete_text"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Source",
        ),
    ]
