{% load generic %}
<table class="table table-hover">
  {% modeldict object as d %}
  {% for key, value in d.items %}
    {% model_field_template_lookup_list object key "table_row" as template_list %}
    {% include template_list %}
  {% endfor %}
</table>
