# Generated by Django 5.1.7 on 2025-04-29 12:47

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("sample_project", "0007_alter_person_forename_alter_versionperson_forename"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="versiongroup",
            name="version_tag",
        ),
        migrations.RemoveField(
            model_name="versionperson",
            name="version_tag",
        ),
        migrations.RemoveField(
            model_name="versionplace",
            name="version_tag",
        ),
    ]
