/* single object view header */
#single-object-header h2 {
    text-align: center;
}

/* navigation between objects (in list) from single object view header */
.prev-in-list {
    float: right;
}

.next-in-list {
    float: left;
}
