# Generated by Django 4.1.10 on 2023-09-13 12:17

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_entities", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="tempentityclass",
            name="text",
        ),
    ]
