{% load i18n %}
<h5 class="card-title">Linked Open Data</h5>
{% if object.uri_set %}
  {% for uri in object.uri_set.all %}
    {% if not uri.internal %}
      <div class="btn-group mb-2">
        <a class="btn btn-sm btn-outline-secondary"
           target="_blank"
           href="{{ uri.uri }}">{{ uri.short_label }}</a>
        {% if object.get_change_permission in perms %}
          <button type="button"
                  class="btn btn-sm btn-outline-secondary dropdown-toggle dropdown-toggle-split"
                  data-bs-toggle="dropdown"
                  aria-expanded="false">
            <span class="visually-hidden">Toggle Dropdown</span>
          </button>
          <ul class="dropdown-menu">
            <li>
              <a href="{{ object.get_enrich_url }}?uri={{ uri.uri }}"
                 class="dropdown-item small">{% translate "... merge data" %}</a>
            </li>
          </ul>
        {% endif %}
      </div>
    {% endif %}
  {% endfor %}
{% endif %}
