{% load i18n %}
<a title="{% translate "delete" %}"
   hx-delete="{{ record.get_api_detail_endpoint }}"
   hx-confirm="{% blocktranslate %}Are your sure you want to delete {{ record }}?{% endblocktranslate %}"
   hx-target="closest tr"
   hx-swap="outerHTML swap:0.3s"
   href="{{ record.get_delete_url }}"
   class="object-delete"><span class="material-symbols-outlined">delete</span></a>
