{% extends "apis_entities/partials/entity_base_nav.html" %}
{% load i18n %}

{% block base-nav-inner %}
  {{ block.super }}
  {% if object.history %}
    <li class="nav-item">
      <a class="nav-link object-history {% if request.path == object.get_history_url %}active{% endif %}"
         href="{{ object.get_history_url }}"><span class="material-symbols-outlined material-symbols-align">history</span>{% translate "History" %}</a>
    </li>
  {% endif %}
{% endblock base-nav-inner %}
