/* object actions */
.object-view {
    color: var(--object-view-color, rgb(25, 135, 84)) !important;
}

.object-edit {
    color: var(--object-edit-color, rgb(255, 193, 7)) !important;
}

.object-delete {
    color: var(--object-delete-color, rgb(220, 53, 69)) !important;
}

.object-duplicate {
    color: var(--object-duplicate-color, blueviolet);
}

.object-merge {
    color: var(--object-merge-color, dodgerblue);
}

.object-history {
    color: var(--object-history-color, #007bff);
}
