{% extends "apis_core/apis_entities/abstractentity.html" %}
{% load django_tables2 %}
{% load history %}
{% load generic %}

{% block navigation %}
  {% load core %}
  {% include "apis_entities/partials/entity_base_nav.html" with object=object.instance %}
{% endblock navigation %}

{% block col-zero %}
  <div class="card">
    {% template_list object "_card_table.html" as template_list %}
    <div class="card-body">{% include template_list %}</div>
  </div>
{% endblock col-zero %}
